@@ -267,73 +267,20 @@ impl Contest {
                 );
             }
 
-            for n in 0..left_braces.len() {
-                if left_braces[n] > right_braces[n] {
-                    return (
-                        Some(TemplateErr(
-                            [
-                                "Nested braces are not supported.\nSee the value `",
-                                unparsed_pdf_path,
-                                "` of key `",
-                                tex_path,
-                                "` in the `texfiles` of template `",
-                                &self.template.0,
-                                "`",
-                            ]
-                            .concat(),
-                        )),
-                        results,
-                    );
-                }
-            }
-
-            for n in 0..left_braces.len() - 1 {
-                if right_braces[n] > left_braces[n + 1] {
-                    return (
-                        Some(TemplateErr(
-                            [
-                                "Nested braces are not supported.\nSee the value `",
-                                unparsed_pdf_path,
-                                "` of key `",
-                                tex_path,
-                                "` in the `texfiles` of template `",
-                                &self.template.0,
-                                "`",
-                            ]
-                            .concat(),
-                        )),
-                        results,
-                    );
-                }
-            }
-
             let mut parsed_pdf_path = String::new();
 
-            for n in 0..left_braces.len() {
-                let key = &unparsed_pdf_path[left_braces[n] + 1..right_braces[n]];
-                match self.vars.get(key) {
-                    Some(val) => {
-                        if n == 0 {
-                            parsed_pdf_path.push_str(&unparsed_pdf_path[..left_braces[n]]);
-                        } else {
-                            parsed_pdf_path.push_str(
-                                &unparsed_pdf_path[right_braces[n - 1] + 1..left_braces[n]],
-                            );
-                        }
-                        parsed_pdf_path.push_str(val);
-                    }
-                    None => {
+            if left_braces.len() > 0 {
+                for n in 0..left_braces.len() {
+                    if left_braces[n] > right_braces[n] {
                         return (
                             Some(TemplateErr(
                                 [
-                                    "The value `",
+                                    "Nested braces are not supported.\nSee the value `",
                                     unparsed_pdf_path,
                                     "` of key `",
                                     tex_path,
                                     "` in the `texfiles` of template `",
                                     &self.template.0,
-                                    "`\nis referencing undefined template variable `",
-                                    key,
                                     "`",
                                 ]
                                 .concat(),
@@ -342,11 +289,67 @@ impl Contest {
                         );
                     }
                 }
+
+                for n in 0..left_braces.len() - 1 {
+                    if right_braces[n] > left_braces[n + 1] {
+                        return (
+                            Some(TemplateErr(
+                                [
+                                    "Nested braces are not supported.\nSee the value `",
+                                    unparsed_pdf_path,
+                                    "` of key `",
+                                    tex_path,
+                                    "` in the `texfiles` of template `",
+                                    &self.template.0,
+                                    "`",
+                                ]
+                                .concat(),
+                            )),
+                            results,
+                        );
+                    }
+                }
+
+                for n in 0..left_braces.len() {
+                    let key = &unparsed_pdf_path[left_braces[n] + 1..right_braces[n]];
+                    match self.vars.get(key) {
+                        Some(val) => {
+                            if n == 0 {
+                                parsed_pdf_path.push_str(&unparsed_pdf_path[..left_braces[n]]);
+                            } else {
+                                parsed_pdf_path.push_str(
+                                    &unparsed_pdf_path[right_braces[n - 1] + 1..left_braces[n]],
+                                );
+                            }
+                            parsed_pdf_path.push_str(val);
+                        }
+                        None => {
+                            return (
+                                Some(TemplateErr(
+                                    [
+                                        "The value `",
+                                        unparsed_pdf_path,
+                                        "` of key `",
+                                        tex_path,
+                                        "` in the `texfiles` of template `",
+                                        &self.template.0,
+                                        "`\nis referencing undefined template variable `",
+                                        key,
+                                        "`",
+                                    ]
+                                    .concat(),
+                                )),
+                                results,
+                            );
+                        }
+                    }
+                }
+
+                parsed_pdf_path
+                    .push_str(&unparsed_pdf_path[right_braces[right_braces.len() - 1] + 1..]);
+            } else {
+                parsed_pdf_path.push_str(&unparsed_pdf_path);
             }
-
-            parsed_pdf_path
-                .push_str(&unparsed_pdf_path[right_braces[right_braces.len() - 1] + 1..]);
-
             let latexmk = Command::new("latexmk").args([&["-pdflatex=", &self.template.1.engine].concat(), "-pdf", "-f", tex_path]).output().expect("Failed to execute latexmk.\nMake sure you have the latexmk script installed\nand make sure it is in your PATH.");
             if latexmk.status.success() {
                 results.push(Ok(["Finished compiling ", &parsed_pdf_path].concat()));
