@@ -9,7 +9,6 @@
 //! A working version of `latexmk`, as well as a properly configured `~/.latexmkrc` file, are required.
 
 pub mod contest;
-pub mod file;
-pub mod mapm_result;
 pub mod problem;
+pub mod result;
 pub mod template;
