@@ -297,22 +297,50 @@ impl Problem {
     }
 
     /// Show only the keys passed in or everything but the keys passed in to a problem
+    ///
+    /// # Usage
+    ///
+    /// ```
+    /// use mapm::problem::Views;
+    /// use mapm::problem::Views::{Show, Hide};
+    /// use mapm::problem::Problem;
+    /// use mapm::problem::parse_problem_yaml;
+    /// use mapm::problem::Filter;
+    /// use std::collections::HashMap;
+    ///
+    /// let problem_yaml = "problem: What is $1+1$?
+    /// author: Dennis Chen
+    /// answer: 2
+    /// solutions:
+    ///   - text: It's $2$.
+    ///     author: Alexander
+    /// ";
+    ///
+    /// let problem = parse_problem_yaml(problem_yaml).unwrap();
+    ///
+    /// let show: Views = Show(Vec::from([String::from("author"), String::from("answer"), String::from("solutions")]));
+    /// let show_filtered_problem = problem.clone().filter_keys(show);
+    /// assert_eq!(show_filtered_problem.0, HashMap::from([(String::from("author"), String::from("Dennis Chen")), (String::from("answer"), String::from("2"))]));
+    /// assert_eq!(show_filtered_problem.1, Some(Vec::from([
+    ///     HashMap::from([(String::from("text"), String::from("It's $2$.")), (String::from("author"), String::from("Alexander"))])
+    /// ])));
+    ///
+    /// let hide: Views = Hide(Vec::from([String::from("solutions"), String::from("author")]));
+    /// let hide_filtered_problem = problem.clone().filter_keys(hide);
+    /// assert_eq!(hide_filtered_problem.0, HashMap::from([(String::from("problem"), String::from("What is $1+1$?")), (String::from("answer"), String::from("2"))]));
+    /// assert_eq!(hide_filtered_problem.1, None);
+    /// ```
 
     pub fn filter_keys(self, views: Views) -> (Vars, Option<Solutions>) {
         match views {
             Show(tags) => {
                 let mut vars: Vars = HashMap::new();
-                let mut solutions: bool = false;
                 for (key, val) in self.vars {
-                    if key == "solutions" {
-                        solutions = true;
-                    } else {
-                        if tags.contains(&key) {
-                            vars.insert(key, val);
-                        }
+                    if key != "solutions" && tags.contains(&key) {
+                        vars.insert(key, val);
                     }
                 }
-                if solutions {
+                if tags.contains(&"solutions".to_string()) {
                     return (vars, Some(self.solutions));
                 } else {
                     return (vars, None);
@@ -320,17 +348,12 @@ impl Problem {
             }
             Hide(tags) => {
                 let mut vars: Vars = HashMap::new();
-                let mut solutions: bool = true;
                 for (key, val) in self.vars {
-                    if key == "solutions" {
-                        solutions = false;
-                    } else {
-                        if !tags.contains(&key) {
-                            vars.insert(key, val);
-                        }
+                    if key != "solutions" && !tags.contains(&key) {
+                        vars.insert(key, val);
                     }
                 }
-                if solutions {
+                if !tags.contains(&"solutions".to_string()) {
                     return (vars, Some(self.solutions));
                 } else {
                     return (vars, None);
